# feeluown-netease

feeluown 网易云音乐插件

## 安装

```sh
pip3 install fuo-netease
```

## changelog

### 0.3 (2019-10-28)

- 支持获取歌手专辑
- 支持获取播放列表的所有歌曲

### 0.2 (2019-06-30)

- 适配 fuocore.models.Media 新设计
- 支持多品质音乐

### 0.1 (2019-03-18)

- 支持用户登录、歌曲搜索、歌词/歌曲/mv/歌手/专辑详情获取
